@@ -73,7 +73,7 @@ enum
 static guint sidebar_signals[LAST_SIGNAL] = { 0 };
 static GQuark sidebar_page_id_quark = 0;
 
-G_DEFINE_TYPE (GdictSidebar, gdict_sidebar, GTK_TYPE_VBOX);
+G_DEFINE_TYPE (GdictSidebar, gdict_sidebar, GTK_TYPE_BOX);
 
 SidebarPage *
 sidebar_page_new (const gchar *id,
@@ -315,6 +315,7 @@ gdict_sidebar_init (GdictSidebar *sidebar)
   GtkWidget *close_button;
   GtkWidget *arrow;
 
+  gtk_orientable_set_orientation (GTK_ORIENTABLE (sidebar), GTK_ORIENTATION_VERTICAL);
   sidebar->priv = priv = GDICT_SIDEBAR_GET_PRIVATE (sidebar);
 
   /* we store all the pages inside the list, but we keep
@@ -327,7 +328,11 @@ gdict_sidebar_init (GdictSidebar *sidebar)
   priv->pages_by_id = g_hash_table_new (g_str_hash, g_str_equal);
 
   /* top option menu */
+#if GTK_CHECK_VERSION (3, 0, 0)
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+#else
   hbox = gtk_hbox_new (FALSE, 0);
+#endif
   gtk_box_pack_start (GTK_BOX (sidebar), hbox, FALSE, FALSE, 0);
   gtk_widget_show (hbox);
   priv->hbox = hbox;
@@ -342,10 +347,19 @@ gdict_sidebar_init (GdictSidebar *sidebar)
 		    sidebar);
   priv->select_button = select_button;
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  select_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+#else
   select_hbox = gtk_hbox_new (FALSE, 0);
+#endif
 
   priv->label = gtk_label_new (NULL);
+#if GTK_CHECK_VERSION (3, 16, 0)
+  gtk_label_set_xalign (GTK_LABEL (priv->label), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (priv->label), 0.5);
+#else
   gtk_misc_set_alignment (GTK_MISC (priv->label), 0.0, 0.5);
+#endif
   gtk_box_pack_start (GTK_BOX (select_hbox), priv->label, FALSE, FALSE, 0);
   gtk_widget_show (priv->label);
 
@@ -362,8 +376,8 @@ gdict_sidebar_init (GdictSidebar *sidebar)
   close_button = gtk_button_new ();
   gtk_button_set_relief (GTK_BUTTON (close_button), GTK_RELIEF_NONE);
   gtk_button_set_image (GTK_BUTTON (close_button),
-		        gtk_image_new_from_stock (GTK_STOCK_CLOSE,
-						  GTK_ICON_SIZE_SMALL_TOOLBAR));
+                        gtk_image_new_from_icon_name ("window-close",
+                                                      GTK_ICON_SIZE_SMALL_TOOLBAR));
   g_signal_connect (close_button, "clicked",
 		    G_CALLBACK (gdict_sidebar_close_clicked_cb),
 		    sidebar);
@@ -446,7 +460,8 @@ gdict_sidebar_add_page (GdictSidebar *sidebar,
   gtk_widget_show (menu_item);
   page->menu_item = menu_item;
 
-  gtk_menu_shell_select_item (GTK_MENU_SHELL (priv->menu), menu_item);
+  if (gtk_widget_get_realized (priv->menu))
+    gtk_menu_shell_select_item (GTK_MENU_SHELL (priv->menu), menu_item);
   gtk_label_set_text (GTK_LABEL (priv->label), page_name);
   gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook), page->index);
 }
@@ -496,7 +511,8 @@ gdict_sidebar_remove_page (GdictSidebar *sidebar,
   page = priv->pages->data;
   if (page)
     {
-      gtk_menu_shell_select_item (GTK_MENU_SHELL (priv->menu), page->menu_item);
+      if (gtk_widget_get_realized (priv->menu))
+        gtk_menu_shell_select_item (GTK_MENU_SHELL (priv->menu), page->menu_item);
       gtk_label_set_text (GTK_LABEL (priv->label), page->name);
       gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook), page->index);
     }
@@ -521,7 +537,8 @@ gdict_sidebar_view_page (GdictSidebar *sidebar,
 
   gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook), page->index);
   gtk_label_set_text (GTK_LABEL (priv->label), page->name);
-  gtk_menu_shell_select_item (GTK_MENU_SHELL (priv->menu), page->menu_item);
+  if (gtk_widget_get_realized (priv->menu))
+    gtk_menu_shell_select_item (GTK_MENU_SHELL (priv->menu), page->menu_item);
 }
 
 const gchar *
